==========================
``psyclone.domain.common``
==========================

.. automodule:: psyclone.domain.common

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.domain.common.algorithm
   psyclone.domain.common.extract_driver_creator
   psyclone.domain.common.psylayer
   psyclone.domain.common.transformations

.. currentmodule:: psyclone.domain.common


Classes
=======

- :py:class:`ExtractDriverCreator`:
  This class provides the functionality to create a driver that


.. autoclass:: ExtractDriverCreator
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ExtractDriverCreator
      :parts: 1
